@@ -28,21 +28,9 @@ sub new {
     return $self;
 }
 
-sub getOptionsFromServer {
-    my ($self, $response, $name, $feature) = @_;
-
-    if (!$response) {
-        $self->{logger}->debug("No server response");
-        return;
-    }
-
-    my $options = $response->getOptionsInfoByName($name);
-    if (!$options) {
-        $self->{logger}->debug("No $feature requested in the prolog");
-        return;
-    }
-
-    return $options;
+sub abort {
+    my ($self) = @_;
+    $self->{logger}->info("aborting task");
 }
 
 sub getModules {
@@ -118,6 +106,10 @@ This is a method to be implemented by each subclass.
 
 This is a method to be implemented by each subclass.
 
+=head2 abort()
+
+Abort running task immediatly.
+
 =head2 getOptionsFromServer($response, $name, $feature)
 
 Get task-specific options in server response to prolog message.
